"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.VelocitySensor = void 0;
var utils_1 = require("../utils");
var VelocitySensor = /** @class */ (function () {
    function VelocitySensor(devAddr, mcuId) {
        this.devAddr = devAddr;
        this.mcuId = mcuId;
        this.types = ['TimeDomainDataInfo', 'RMSSpeedStatus', 'AccPeakStatus', 'FreqData'];
        this.statuses = ['GOOD', 'WARNING', 'ALARM'];
        this.MAX_VALUE = 5.0;
    }
    VelocitySensor.prototype.getRandomStatus = function () {
        return this.statuses[(0, utils_1.randomNumberInRange)(0, this.statuses.length - 1)];
    };
    VelocitySensor.prototype.getTimeDomainDataInfo = function () {
        return {
            DevAddr: this.devAddr,
            Type: this.types[0],
            MCU_ID: this.mcuId,
            Data: {
                X_AccPeak: (0, utils_1.randomNumberInRange)(0.0, this.MAX_VALUE, false),
                X_RMS_Speed: (0, utils_1.randomNumberInRange)(0, this.MAX_VALUE, false),
                Y_AccPeak: (0, utils_1.randomNumberInRange)(0.0, this.MAX_VALUE, false),
                Y_RMS_Speed: (0, utils_1.randomNumberInRange)(0.0, this.MAX_VALUE, false),
                Z_AccPeak: (0, utils_1.randomNumberInRange)(0.0, this.MAX_VALUE, false),
                Z_RMS_Speed: (0, utils_1.randomNumberInRange)(0.0, this.MAX_VALUE, false)
            }
        };
    };
    VelocitySensor.prototype.getRMSSpeedStatus = function () {
        return {
            DevAddr: this.devAddr,
            Type: this.types[1],
            MCU_ID: this.mcuId,
            Data: [
                { X_Status: this.getRandomStatus(), X_Value: (0, utils_1.randomNumberInRange)(0.0, this.MAX_VALUE, false), X_Unit: "mm/s" },
                { Y_Status: this.getRandomStatus(), Y_Value: (0, utils_1.randomNumberInRange)(0.0, this.MAX_VALUE, false), Y_Unit: "mm/s" },
                { Z_Status: this.getRandomStatus(), Z_Value: (0, utils_1.randomNumberInRange)(0.0, this.MAX_VALUE, false), Z_Unit: "mm/s" },
            ]
        };
    };
    VelocitySensor.prototype.getAccPeakStatus = function () {
        return {
            DevAddr: this.devAddr,
            Type: this.types[2],
            MCU_ID: this.mcuId,
            Data: [
                { X_Status: this.getRandomStatus(), X_AccPeak: (0, utils_1.randomNumberInRange)(0.0, this.MAX_VALUE, false), X_AccPeakUnit: "m/s^2" },
                { Y_Status: this.getRandomStatus(), Y_AccPeak: (0, utils_1.randomNumberInRange)(0.0, this.MAX_VALUE, false), Y_AccPeakUnit: "m/s^2" },
                { Z_Status: this.getRandomStatus(), Z_AccPeak: (0, utils_1.randomNumberInRange)(0.0, this.MAX_VALUE, false), Z_AccPeakUnit: "m/s^2" },
            ]
        };
    };
    VelocitySensor.prototype.getFreqData = function () {
        return {
            DevAddr: this.devAddr,
            Type: this.types[3],
            MCU_ID: this.mcuId,
            Data: [
                { X_Status: this.getRandomStatus(), X_Max_Value: (0, utils_1.randomNumberInRange)(0.0, this.MAX_VALUE, false), X_Max_Freq: (0, utils_1.randomNumberInRange)(0.0, 1000.0, false), X_Max_FreqUnit: "Hz" },
                { Y_Status: this.getRandomStatus(), Y_Max_Value: (0, utils_1.randomNumberInRange)(0.0, this.MAX_VALUE, false), Y_Max_Freq: (0, utils_1.randomNumberInRange)(0.0, 1000.0, false), Y_Max_FreqUnit: "Hz" },
                { Z_Status: this.getRandomStatus(), Z_Max_Value: (0, utils_1.randomNumberInRange)(0.0, this.MAX_VALUE, false), Z_Max_Freq: (0, utils_1.randomNumberInRange)(0.0, 1000.0, false), Z_Max_FreqUnit: "Hz" },
            ]
        };
    };
    VelocitySensor.prototype.getData = function () {
        return [this.getTimeDomainDataInfo(), this.getRMSSpeedStatus(), this.getAccPeakStatus(), this.getFreqData()];
    };
    return VelocitySensor;
}());
exports.VelocitySensor = VelocitySensor;
